@@ -13,16 +13,21 @@ import shutil
 
 from textwrap import dedent
 
-from html2image.browsers import chrome, firefox
+from html2image.browsers import chrome, chrome_cdp#, firefox, firefox_cdp
+from html2image.browsers.browser import CDPBrowser
 
 browser_map = {
     'chrome': chrome.ChromeHeadless,
     'chromium': chrome.ChromeHeadless,
     'google-chrome': chrome.ChromeHeadless,
-    'googlechrome': chrome.ChromeHeadless,
-    'firefox': firefox.FirefoxHeadless,
-    'mozilla-firefox': firefox.FirefoxHeadless,
-    'mozilla firefox': firefox.FirefoxHeadless,
+
+    'chrome-cdp': chrome_cdp.ChromeCDP,
+    'chromium-cdp': chrome_cdp.ChromeCDP,
+
+    # 'firefox': firefox.FirefoxHeadless,
+    # 'mozilla-firefox': firefox.FirefoxHeadless,
+
+    # 'firefox-cdp': firefox_cdp.FirefoxCDP,
 }
 
 
@@ -37,7 +42,7 @@ class Html2Image():
             + Type of the browser that will be used to take screenshots.
             + Default is Chrome.
 
-        - `browser_path` : str, optional
+        - `browser_executable` : str, optional
             + Path to a browser executable.
 
         - `output_path` : str, optional
@@ -64,11 +69,13 @@ class Html2Image():
     def __init__(
         self,
         browser='chrome',
-        browser_path=None,
+        browser_executable=None,
+        browser_cdp_port=None,
         output_path=os.getcwd(),
         size=(1920, 1080),
         temp_path=None,
-        custom_flags=[],
+        custom_flags=None,
+        disable_logging=False,
     ):
 
         if browser.lower() not in browser_map:
@@ -81,10 +88,20 @@ class Html2Image():
         self.temp_path = temp_path
 
         browser_class = browser_map[browser.lower()]
-        self.browser = browser_class(
-            executable_path=browser_path,
-            flags=custom_flags,
-        )
+
+        if isinstance(browser_class, CDPBrowser):
+            self.browser = browser_class(
+                executable=browser_executable,
+                flags=custom_flags,
+                cdp_port=browser_cdp_port,
+                disable_logging=disable_logging,
+            )
+        else:
+            self.browser = browser_class(
+                executable=browser_executable,
+                flags=custom_flags,
+                disable_logging=disable_logging,
+            )
 
     @property
     def temp_path(self):
@@ -515,6 +532,13 @@ class Html2Image():
 
         return screenshot_paths
 
+    def __enter__(self):
+        self.browser.__enter__()
+        return self
+
+    def __exit__(self, *exc):
+        self.browser.__exit__(*exc)
+
 
 if __name__ == '__main__':
     pass
